import { Route, Routes } from 'react-router-dom'
import { BrowserRouter as Router } from 'react-router-dom'
import './app.css'
import { DefaultLayout } from './layouts'
import "yet-another-react-lightbox/styles.css";
import { Login, NotFound, Submissions } from './pages'
import { Provider } from 'react-redux'
import { persistore, store } from './store/config'
import { PersistGate } from 'redux-persist/integration/react'
import { AdminProtectedRoute, UserProtectedRoute } from './routes/ProtectedRoute'
import { getRoutes } from './routes';


export function App() {
  const { routes } = getRoutes();
  return (
    <>
      <Provider store={store}>
        <PersistGate persistor={persistore}>
          <Router>
            <Routes>
              <Route path='/login' element={<Login />} />
              <Route element={<DefaultLayout />}>
                {routes.map(({ path, name, element, protectedRoute }) => {
                  let Element = element as any
                  if (protectedRoute === "user") {
                    return (
                      <>
                        <Route
                          path={path}
                          id={name}
                          element={
                            <UserProtectedRoute>
                              <Element />
                            </UserProtectedRoute>
                          }
                        />
                      </>
                    )
                  }

                  if (protectedRoute === "admin") {
                    return (
                      <>
                        <>
                          <Route
                            path={path}
                            id={name}
                            element={
                              <AdminProtectedRoute>
                                <Element />
                              </AdminProtectedRoute>
                            }
                          />
                        </>
                      </>
                    )
                  }
                  return (
                    <>
                      <Route
                        path={path}
                        id={name}
                        element={element}
                      />
                    </>
                  )
                })}
                <Route path="*" element={<NotFound />} />
              </Route>
            </Routes>
          </Router>
        </PersistGate>
      </Provider>
    </>
  )
}
