import {
  BestLocation,
  Discovery,
  Home,
  LocationDetail,
  NewsEvent,
  Story,
  AddLocation,
  UserProfile,
  UserFeed,
  UserSettings,
  Submissions
} from '../pages';

interface BaseRoutes {
  path: string,
  name: string,
  protectedRoute?: string,
  element: any
}

export interface IRoutes {
  routes: Array<BaseRoutes>
}

export const getRoutes = (): IRoutes => {
  let groupRoutes: Array<BaseRoutes> = [
    {
      path: "/",
      name: "Home",
      element: <Home />
    },
    {
      path: "/best-places",
      name: "Home",
      element: <BestLocation />
    },
    {
      path: "/discover",
      name: "Home",
      element: <Discovery />
    },
    {
      path: "/stories",
      name: "Home",
      element: <Story />
    },
    {
      path: "/news-events",
      name: "Home",
      element: <NewsEvent />
    },
    {
      path: "/location/:id",
      name: "LocationDetail",
      element: <LocationDetail />
    },
    // PROTECTED USER ROUTES
    {
      path: "/add-location",
      name: "AddLocation",
      protectedRoute: "user",
      element: AddLocation
    },
    {
      path: "/user/profile",
      name: "UserProfile",
      protectedRoute: "user",
      element: UserProfile
    },
    {
      path: "/user/settings",
      name: "UserSettings",
      protectedRoute: "user",
      element: UserSettings
    },
    {
      path: "/user/feed",
      name: "UserFeed",
      protectedRoute: "user",
      element: UserFeed
    },
    //PROTECTED ADMIN ROUTES
    {
      path: "/admin/submissions",
      name: "Submissions",
      protectedRoute: "admin",
      element: Submissions
    },
  ]

  let routes: IRoutes = {
    routes: groupRoutes
  }

  return routes

}